==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkMultiBlockPLOT3DReader.java <==
// java wrapper for vtkMultiBlockPLOT3DReader object
//

package vtk;
import vtk.*;

public class vtkMultiBlockPLOT3DReader extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetXYZFileName_4(String id0);
  public void SetXYZFileName(String id0)
    { SetXYZFileName_4(id0); }

  private native String GetXYZFileName_5();
  public String GetXYZFileName()
    { return GetXYZFileName_5(); }

  private native void SetQFileName_6(String id0);
  public void SetQFileName(String id0)
    { SetQFileName_6(id0); }

  private native String GetQFileName_7();
  public String GetQFileName()
    { return GetQFileName_7(); }

  private native void SetFunctionFileName_8(String id0);
  public void SetFunctionFileName(String id0)
    { SetFunctionFileName_8(id0); }

  private native String GetFunctionFileName_9();
  public String GetFunctionFileName()
    { return GetFunctionFileName_9(); }

  private native void SetAutoDetectFormat_10(int id0);
  public void SetAutoDetectFormat(int id0)
    { SetAutoDetectFormat_10(id0); }

  private native int GetAutoDetectFormat_11();
  public int GetAutoDetectFormat()
    { return GetAutoDetectFormat_11(); }

  private native void AutoDetectFormatOn_12();
  public void AutoDetectFormatOn()
    { AutoDetectFormatOn_12(); }

  private native void AutoDetectFormatOff_13();
  public void AutoDetectFormatOff()
    { AutoDetectFormatOff_13(); }

  private native void SetBinaryFile_14(int id0);
  public void SetBinaryFile(int id0)
    { SetBinaryFile_14(id0); }

  private native int GetBinaryFile_15();
  public int GetBinaryFile()
    { return GetBinaryFile_15(); }

  private native void BinaryFileOn_16();
  public void BinaryFileOn()
    { BinaryFileOn_16(); }

  private native void BinaryFileOff_17();
  public void BinaryFileOff()
    { BinaryFileOff_17(); }

  private native void SetMultiGrid_18(int id0);
  public void SetMultiGrid(int id0)
    { SetMultiGrid_18(id0); }

  private native int GetMultiGrid_19();
  public int GetMultiGrid()
    { return GetMultiGrid_19(); }

  private native void MultiGridOn_20();
  public void MultiGridOn()
    { MultiGridOn_20(); }

  private native void MultiGridOff_21();
  public void MultiGridOff()
    { MultiGridOff_21(); }

  private native void SetHasByteCount_22(int id0);
  public void SetHasByteCount(int id0)
    { SetHasByteCount_22(id0); }

  private native int GetHasByteCount_23();
  public int GetHasByteCount()
    { return GetHasByteCount_23(); }

  private native void HasByteCountOn_24();
  public void HasByteCountOn()
    { HasByteCountOn_24(); }

  private native void HasByteCountOff_25();
  public void HasByteCountOff()
    { HasByteCountOff_25(); }

  private native void SetIBlanking_26(int id0);
  public void SetIBlanking(int id0)
    { SetIBlanking_26(id0); }

  private native int GetIBlanking_27();
  public int GetIBlanking()
    { return GetIBlanking_27(); }

  private native void IBlankingOn_28();
  public void IBlankingOn()
    { IBlankingOn_28(); }

  private native void IBlankingOff_29();
  public void IBlankingOff()
    { IBlankingOff_29(); }

  private native void SetTwoDimensionalGeometry_30(int id0);
  public void SetTwoDimensionalGeometry(int id0)
    { SetTwoDimensionalGeometry_30(id0); }

  private native int GetTwoDimensionalGeometry_31();
  public int GetTwoDimensionalGeometry()
    { return GetTwoDimensionalGeometry_31(); }

  private native void TwoDimensionalGeometryOn_32();
  public void TwoDimensionalGeometryOn()
    { TwoDimensionalGeometryOn_32(); }

  private native void TwoDimensionalGeometryOff_33();
  public void TwoDimensionalGeometryOff()
    { TwoDimensionalGeometryOff_33(); }

  private native void SetDoublePrecision_34(int id0);
  public void SetDoublePrecision(int id0)
    { SetDoublePrecision_34(id0); }

  private native int GetDoublePrecision_35();
  public int GetDoublePrecision()
    { return GetDoublePrecision_35(); }

  private native void DoublePrecisionOn_36();
  public void DoublePrecisionOn()
    { DoublePrecisionOn_36(); }

  private native void DoublePrecisionOff_37();
  public void DoublePrecisionOff()
    { DoublePrecisionOff_37(); }

  private native void SetForceRead_38(int id0);
  public void SetForceRead(int id0)
    { SetForceRead_38(id0); }

  private native int GetForceRead_39();
  public int GetForceRead()
    { return GetForceRead_39(); }

  private native void ForceReadOn_40();
  public void ForceReadOn()
    { ForceReadOn_40(); }

  private native void ForceReadOff_41();
  public void ForceReadOff()
    { ForceReadOff_41(); }

  private native void SetByteOrderToBigEndian_42();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_42(); }

  private native void SetByteOrderToLittleEndian_43();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_43(); }

  private native void SetByteOrder_44(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_44(id0); }

  private native int GetByteOrder_45();
  public int GetByteOrder()
    { return GetByteOrder_45(); }

  private native String GetByteOrderAsString_46();
  public String GetByteOrderAsString()
    { return GetByteOrderAsString_46(); }

  private native void SetR_47(double id0);
  public void SetR(double id0)
    { SetR_47(id0); }

  private native double GetR_48();
  public double GetR()
    { return GetR_48(); }

  private native void SetGamma_49(double id0);
  public void SetGamma(double id0)
    { SetGamma_49(id0); }

  private native double GetGamma_50();
  public double GetGamma()
    { return GetGamma_50(); }

  private native void SetScalarFunctionNumber_51(int id0);
  public void SetScalarFunctionNumber(int id0)
    { SetScalarFunctionNumber_51(id0); }

  private native int GetScalarFunctionNumber_52();
  public int GetScalarFunctionNumber()
    { return GetScalarFunctionNumber_52(); }

  private native void SetVectorFunctionNumber_53(int id0);
  public void SetVectorFunctionNumber(int id0)
    { SetVectorFunctionNumber_53(id0); }

  private native int GetVectorFunctionNumber_54();
  public int GetVectorFunctionNumber()
    { return GetVectorFunctionNumber_54(); }

  private native void AddFunction_55(int id0);
  public void AddFunction(int id0)
    { AddFunction_55(id0); }

  private native void RemoveFunction_56(int id0);
  public void RemoveFunction(int id0)
    { RemoveFunction_56(id0); }

  private native void RemoveAllFunctions_57();
  public void RemoveAllFunctions()
    { RemoveAllFunctions_57(); }

  private native int CanReadBinaryFile_58(String id0);
  public int CanReadBinaryFile(String id0)
    { return CanReadBinaryFile_58(id0); }

  private native void SetController_59(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_59(id0); }

  private native long GetController_60();
  public vtkMultiProcessController GetController() {
    long temp = GetController_60();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkMultiBlockPLOT3DReader() { super(); }

  public vtkMultiBlockPLOT3DReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-aarch64.pkg.tar.xz: vtk/vtkMultiBlockPLOT3DReader.java <==
// java wrapper for vtkMultiBlockPLOT3DReader object
//

package vtk;
import vtk.*;

public class vtkMultiBlockPLOT3DReader extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetXYZFileName_4(String id0);
  public void SetXYZFileName(String id0)
    { SetXYZFileName_4(id0); }

  private native String GetXYZFileName_5();
  public String GetXYZFileName()
    { return GetXYZFileName_5(); }

  private native void SetQFileName_6(String id0);
  public void SetQFileName(String id0)
    { SetQFileName_6(id0); }

  private native String GetQFileName_7();
  public String GetQFileName()
    { return GetQFileName_7(); }

  private native void SetFunctionFileName_8(String id0);
  public void SetFunctionFileName(String id0)
    { SetFunctionFileName_8(id0); }

  private native String GetFunctionFileName_9();
  public String GetFunctionFileName()
    { return GetFunctionFileName_9(); }

  private native void SetAutoDetectFormat_10(int id0);
  public void SetAutoDetectFormat(int id0)
    { SetAutoDetectFormat_10(id0); }

  private native int GetAutoDetectFormat_11();
  public int GetAutoDetectFormat()
    { return GetAutoDetectFormat_11(); }

  private native void AutoDetectFormatOn_12();
  public void AutoDetectFormatOn()
    { AutoDetectFormatOn_12(); }

  private native void AutoDetectFormatOff_13();
  public void AutoDetectFormatOff()
    { AutoDetectFormatOff_13(); }

  private native void SetBinaryFile_14(int id0);
  public void SetBinaryFile(int id0)
    { SetBinaryFile_14(id0); }

  private native int GetBinaryFile_15();
  public int GetBinaryFile()
    { return GetBinaryFile_15(); }

  private native void BinaryFileOn_16();
  public void BinaryFileOn()
    { BinaryFileOn_16(); }

  private native void BinaryFileOff_17();
  public void BinaryFileOff()
    { BinaryFileOff_17(); }

  private native void SetMultiGrid_18(int id0);
  public void SetMultiGrid(int id0)
    { SetMultiGrid_18(id0); }

  private native int GetMultiGrid_19();
  public int GetMultiGrid()
    { return GetMultiGrid_19(); }

  private native void MultiGridOn_20();
  public void MultiGridOn()
    { MultiGridOn_20(); }

  private native void MultiGridOff_21();
  public void MultiGridOff()
    { MultiGridOff_21(); }

  private native void SetHasByteCount_22(int id0);
  public void SetHasByteCount(int id0)
    { SetHasByteCount_22(id0); }

  private native int GetHasByteCount_23();
  public int GetHasByteCount()
    { return GetHasByteCount_23(); }

  private native void HasByteCountOn_24();
  public void HasByteCountOn()
    { HasByteCountOn_24(); }

  private native void HasByteCountOff_25();
  public void HasByteCountOff()
    { HasByteCountOff_25(); }

  private native void SetIBlanking_26(int id0);
  public void SetIBlanking(int id0)
    { SetIBlanking_26(id0); }

  private native int GetIBlanking_27();
  public int GetIBlanking()
    { return GetIBlanking_27(); }

  private native void IBlankingOn_28();
  public void IBlankingOn()
    { IBlankingOn_28(); }

  private native void IBlankingOff_29();
  public void IBlankingOff()
    { IBlankingOff_29(); }

  private native void SetTwoDimensionalGeometry_30(int id0);
  public void SetTwoDimensionalGeometry(int id0)
    { SetTwoDimensionalGeometry_30(id0); }

  private native int GetTwoDimensionalGeometry_31();
  public int GetTwoDimensionalGeometry()
    { return GetTwoDimensionalGeometry_31(); }

  private native void TwoDimensionalGeometryOn_32();
  public void TwoDimensionalGeometryOn()
    { TwoDimensionalGeometryOn_32(); }

  private native void TwoDimensionalGeometryOff_33();
  public void TwoDimensionalGeometryOff()
    { TwoDimensionalGeometryOff_33(); }

  private native void SetDoublePrecision_34(int id0);
  public void SetDoublePrecision(int id0)
    { SetDoublePrecision_34(id0); }

  private native int GetDoublePrecision_35();
  public int GetDoublePrecision()
    { return GetDoublePrecision_35(); }

  private native void DoublePrecisionOn_36();
  public void DoublePrecisionOn()
    { DoublePrecisionOn_36(); }

  private native void DoublePrecisionOff_37();
  public void DoublePrecisionOff()
    { DoublePrecisionOff_37(); }

  private native void SetForceRead_38(int id0);
  public void SetForceRead(int id0)
    { SetForceRead_38(id0); }

  private native int GetForceRead_39();
  public int GetForceRead()
    { return GetForceRead_39(); }

  private native void ForceReadOn_40();
  public void ForceReadOn()
    { ForceReadOn_40(); }

  private native void ForceReadOff_41();
  public void ForceReadOff()
    { ForceReadOff_41(); }

  private native void SetByteOrderToBigEndian_42();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_42(); }

  private native void SetByteOrderToLittleEndian_43();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_43(); }

  private native void SetByteOrder_44(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_44(id0); }

  private native int GetByteOrder_45();
  public int GetByteOrder()
    { return GetByteOrder_45(); }

  private native String GetByteOrderAsString_46();
  public String GetByteOrderAsString()
    { return GetByteOrderAsString_46(); }

  private native void SetR_47(double id0);
  public void SetR(double id0)
    { SetR_47(id0); }

  private native double GetR_48();
  public double GetR()
    { return GetR_48(); }

  private native void SetGamma_49(double id0);
  public void SetGamma(double id0)
    { SetGamma_49(id0); }

  private native double GetGamma_50();
  public double GetGamma()
    { return GetGamma_50(); }

  private native void SetPreserveIntermediateFunctions_51(boolean id0);
  public void SetPreserveIntermediateFunctions(boolean id0)
    { SetPreserveIntermediateFunctions_51(id0); }

  private native boolean GetPreserveIntermediateFunctions_52();
  public boolean GetPreserveIntermediateFunctions()
    { return GetPreserveIntermediateFunctions_52(); }

  private native void PreserveIntermediateFunctionsOn_53();
  public void PreserveIntermediateFunctionsOn()
    { PreserveIntermediateFunctionsOn_53(); }

  private native void PreserveIntermediateFunctionsOff_54();
  public void PreserveIntermediateFunctionsOff()
    { PreserveIntermediateFunctionsOff_54(); }

  private native void SetScalarFunctionNumber_55(int id0);
  public void SetScalarFunctionNumber(int id0)
    { SetScalarFunctionNumber_55(id0); }

  private native int GetScalarFunctionNumber_56();
  public int GetScalarFunctionNumber()
    { return GetScalarFunctionNumber_56(); }

  private native void SetVectorFunctionNumber_57(int id0);
  public void SetVectorFunctionNumber(int id0)
    { SetVectorFunctionNumber_57(id0); }

  private native int GetVectorFunctionNumber_58();
  public int GetVectorFunctionNumber()
    { return GetVectorFunctionNumber_58(); }

  private native void AddFunction_59(int id0);
  public void AddFunction(int id0)
    { AddFunction_59(id0); }

  private native void RemoveFunction_60(int id0);
  public void RemoveFunction(int id0)
    { RemoveFunction_60(id0); }

  private native void RemoveAllFunctions_61();
  public void RemoveAllFunctions()
    { RemoveAllFunctions_61(); }

  private native int CanReadBinaryFile_62(String id0);
  public int CanReadBinaryFile(String id0)
    { return CanReadBinaryFile_62(id0); }

  private native void SetController_63(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_63(id0); }

  private native long GetController_64();
  public vtkMultiProcessController GetController() {
    long temp = GetController_64();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddFunctionName_65(String id0);
  public void AddFunctionName(String id0)
    { AddFunctionName_65(id0); }

  public vtkMultiBlockPLOT3DReader() { super(); }

  public vtkMultiBlockPLOT3DReader(long id) { super(id); }
  public native long   VTKInit();

}
